@@ -14,11 +14,11 @@ userpwd <- NULL
 #' @return A \code{data.frame} class object.
 #' @examples
 #' \donttest{
-#' ind <- dataindex()
+#' ind <- datasets()
 #' View(ind)
 #' }
 #' @export
-dataindex <- function(datadir=NULL, verbose=FALSE){
+datasets <- function(datadir=NULL, verbose=FALSE){
 		
 	# if it does not exist in datadir, then 
 	# by default, download the file
@@ -84,26 +84,39 @@ dataindex <- function(datadir=NULL, verbose=FALSE){
 	return(ret)
 }
 
+#' Deprecated function for data fetching
+#' 
+#' This function will be removed in version 0.3.0.
+#' 
+#' @param ... Arguments passed to the \code{\link{datasets}} function. 
+#' @return The output of the \code{\link{datasets}} function.
+#' @export
+dataindex  <- function(...){
+	message("This function is deprecated, and will be removed in chronosphere v0.3.0.\nPlease use datasets() instead.")
+	datasets(...)
+}
+
 #' Data fetching
 #' 
 #' Function to download and attach variables in the \code{chronosphere} package
 #' 
-#' Use the function \code{\link{dataindex}} to find available variables.
-#' @param dat The dataset to get variables from.
-#' @param var Vector of variable names to get.
-#' @param res The resolution of raster layers. This has to be the same for all RasterLayers that make up the variable.
-#' @param ver The version of the variable. Defaults to \code{NULL}, which will download the latest available version. We have to create a data table, which should be part of the package. This has to be searched for valid argument combinations. Right this is just a folder with a date.
-#' @param datadir Directory where downloaded files are kept. Individual layers will be looked up from the directory if this is given, and will be downloaded if they are not found. The default \code{NULL} option will download data to a temporary directory that exists only until the R session ends.
-#' @param verbose Should console feedback during download be displayed?
+#' Use the function \code{\link{datasets}} to find available variables.
+#' @param dat (\code{character}) The dataset to get variables from.
+#' @param var (\code{character}) Vector of variable names to get.
+#' @param res (\code{character} or \code{numeric}) The resolution of raster layers. This has to be the same for all RasterLayers that make up the variable.
+#' @param ver (\code{character}) The version of the variable. Defaults to \code{NULL}, which will download the latest available version. We have to create a data table, which should be part of the package. This has to be searched for valid argument combinations. Right this is just a folder with a date.
+#' @param datadir (\code{character}) Directory where downloaded files are kept. Individual layers will be looked up from the directory if this is given, and will be downloaded if they are not found. The default \code{NULL} option will download data to a temporary directory that exists only until the R session ends.
+#' @param verbose (\code{logical}) Should console feedback during download be displayed?
+#' @param ... Arguments passed to variable-specific loading functions.
 #' @examples
 #' \donttest{
 #' 	a <- fetch(dat="paleomap", var="dem")
 #' }
 #' @export
-#' @return An object that matches the 'type' field of the varibles in the output of the \code{\link{dataindex}} function.
-fetch <- function(dat, var=NULL, ver=NULL, res=1, datadir=NULL, verbose=TRUE){
+#' @return An object that matches the 'type' field of the varibles in the output of the \code{\link{datasets}} function.
+fetch <- function(dat, var=NULL, ver=NULL, res=NULL, datadir=NULL, verbose=TRUE,...){
 	# get the remote server data, or read it from hard drive!
-	register <- dataindex(datadir=datadir, verbose=verbose)
+	register <- datasets(datadir=datadir, verbose=verbose)
 	
 	# the data have to use the same resolution!!!
 	if(length(dat)>1) stop("Only one dataset can be accessed in a single download call.")
@@ -150,19 +163,19 @@ fetch <- function(dat, var=NULL, ver=NULL, res=1, datadir=NULL, verbose=TRUE){
 	
 
 	# method dispatch
-	if(varType=="RasterArray"){
-		combined <- fetchRaster(dat=dat, var=var, ver=ver, res=res, datadir=datadir, register=register, verbose=verbose)
+	if(varType=="RasterArray" | varType=="SpatialPolygonsDataFrame"){
+		combined <- fetchRemote(dat=dat, var=var, ver=ver, res=res, datadir=datadir, register=register, verbose=verbose,...)
 	}
 
 	if(varType=="data.frame"){
 		# check for non-related input
-		if(res!=1) warning("Argument 'res' is ignored for data.frame fetching.")
+		if(!is.null(res)) warning("Argument 'res' is ignored for data.frame fetching.")
 		combined <- fetchDF(dat=dat, var=var, ver=ver, datadir=datadir, register=register, verbose=verbose)
 	}
 
 	if(varType=="platemodel"){
 		# check for non-related input
-		if(res!=1) warning("Argument 'res' is ignored for plate model fetching.")
+		if(!is.null(res)) warning("Argument 'res' is ignored for plate model fetching.")
 		combined <- fetchModel(dat=dat, var=var, ver=ver, datadir=datadir, register=register, verbose=verbose)
 	}
 
@@ -360,14 +373,24 @@ fetchDF <- function(dat, var, ver, datadir, register, verbose=TRUE){
 
 
 # Raster-specific submodule of fetch()
-fetchRaster <- function(dat, var, res=1, ver=NULL, datadir=NULL, register=register, verbose=TRUE){
+fetchRemote <- function(dat, var, res=NULL, ver=NULL, datadir=NULL, register=register, verbose=TRUE,...){
 	if(! requireNamespace("ncdf4", quietly=TRUE)) stop("This method requires the 'ncdf4' package to run.")
 	
 	# the data have to use the same resolution!!!
-	if(length(res)>1) stop("Only one resolution can be used in a single download call.")
+	if(!is.null(res)) if(length(res)>1) stop("Only one resolution can be used in a single download call.")
 
+	# default resolution used
+	noRes <- FALSE
 	# subset the register to the resolution of interest
-	register <- register[register[, "res"]==res, , drop=FALSE] 
+	if(!is.null(res)){
+		register <- register[register[, "res"]==res, , drop=FALSE]
+	
+	# select the coarsest resolution
+	}else{
+		res <- max(register[, "res"])
+		# if res is NA, than the dataset has no resolution variable
+		if(is.na(res)) noRes <- TRUE
+	}
 
 	# check whether resolution is there, before the download
 	for(j in 1:length(var)){
@@ -418,8 +441,12 @@ fetchRaster <- function(dat, var, res=1, ver=NULL, datadir=NULL, register=regist
 		}
 		
 		# Check whether download is required or not
-		# the name of the res_variable_ver-specific archive
-		archive<- paste(resChar,"_",  var[j],"_", version, ".zip", sep="")
+		if(noRes){
+			archive <- paste(var[j],"_", version, ".zip", sep="")
+		}else{
+			# the name of the res_variable_ver-specific archive
+			archive <- paste(resChar,"_",  var[j],"_", version, ".zip", sep="")
+		}
 
 		# we need a temporary directory to store the extracted files until the end of the session
 		tempd <- tempdir()
@@ -460,7 +487,6 @@ fetchRaster <- function(dat, var, res=1, ver=NULL, datadir=NULL, register=regist
 				download.file(paste("ftp://", userpwd, "@",remote, dat,"/",  var[j], "/", archive,  sep = ""),temp, mode="wb", quiet=!verbose)
 			}
 			
-		
 			# unzip it in temporary directory
 			unzip(temp, exdir=tempd)
 		
@@ -478,7 +504,9 @@ fetchRaster <- function(dat, var, res=1, ver=NULL, datadir=NULL, register=regist
 		source(file.path(varDir, loadScript))
 
 		# run the function that loads in the variable and save it
-		varObj[[j]] <- loadVar(variable=var[j], version=version, resChar=resChar, dir=varDir)
+		varObj[[j]] <- loadVar(variable=var[j], version=version, resChar=resChar, dir=varDir, ...)
+
+		#
 
 		# 'get rid of' temporary directory
 		unlink(tempd)
